@@ -621,7 +621,7 @@ def bSetAsyncHttpMaxNum(value):
 
 
 async def bAsyncHttpGet(url, headers=None, timeout=30, retry=3):
-    import aiohttp
+    importAioHttp()
     global _currentAsyncHttpNum
     headers = _getHeaderByDefault(headers)
     result = None
@@ -634,7 +634,7 @@ async def bAsyncHttpGet(url, headers=None, timeout=30, retry=3):
         currentTry += 1
         try:
             response = None
-            async with aiohttp.ClientSession() as session:
+            async with eval("aiohttp").ClientSession() as session:
                 response = await session.get(
                     url,
                     headers=headers,
@@ -655,7 +655,7 @@ async def bAsyncHttpGet(url, headers=None, timeout=30, retry=3):
 
 
 async def bAsyncHttpPost(url, data=None, headers=None, timeout=30, retry=3):
-    import aiohttp
+    importAioHttp()
     global _currentAsyncHttpNum
     headers = _getHeaderByDefault(headers)
     result = None
@@ -668,7 +668,7 @@ async def bAsyncHttpPost(url, data=None, headers=None, timeout=30, retry=3):
         currentTry += 1
         try:
             response = None
-            async with aiohttp.ClientSession() as session:
+            async with eval("aiohttp").ClientSession() as session:
                 response = await session.post(
                     url,
                     data=data,
@@ -689,6 +689,34 @@ async def bAsyncHttpPost(url, data=None, headers=None, timeout=30, retry=3):
     return result, response
 
 
+isImportAioHttp = True
+
+
+def importAioHttp():
+
+    global isImportAioHttp
+
+    if isImportAioHttp:
+        isImportAioHttp = False
+
+        import aiohttp
+        from functools import wraps
+        from asyncio.proactor_events import _ProactorBasePipeTransport
+
+        # 尝试优化报错：RuntimeError: Event loop is closed
+
+        def silence_event_loop_closed(func):
+            @wraps(func)
+            def wrapper(self, *args, **kwargs):
+                try:
+                    return func(self, *args, **kwargs)
+                except RuntimeError as e:
+                    if str(e) != 'Event loop is closed':
+                        raise
+            return wrapper
+
+        _ProactorBasePipeTransport.__del__ = silence_event_loop_closed(_ProactorBasePipeTransport.__del__)
+
 # def bScrapy(urlList, parseFun, extendSettings=None):
 
 #     from scrapy.crawler import CrawlerProcess
